import React from 'react';
import dynamic from 'dva/dynamic';
import { getMenuData } from './menu';

// wrapper of dynamic
const dynamicWrapper = (app, models, component) => dynamic({
  app,
  // eslint-disable-next-line no-underscore-dangle
  models: () => models.filter(m => !app._models.some(({ namespace }) => namespace === m)).map(m => import(`../models/${m}.js`)),
  // add routerData prop
  component: () => {
    const p = component();
    return new Promise((resolve, reject) => {
      p.then((Comp) => {
        resolve(props => <Comp {...props} routerData={getRouterData(app)} />);
      }).catch(err => reject(err));
    });
  },
});

function getFlatMenuData(menus) {
  let keys = {};
  menus.forEach((item) => {
    if (item.children) {
      keys[item.path] = item.name;
      keys = { ...keys, ...getFlatMenuData(item.children) };
    } else {
      keys[item.path] = item.name;
    }
  });
  return keys;
}

export const getRouterData = (app) => {
  const routerData = {
    '/': {
      component: dynamicWrapper(app, ['user', 'login'], () => import('../layouts/BasicLayout')),
    },
    '/resource/gallery': {
      component: dynamicWrapper(app, ['resource'], () => import('../routes/Resource/gallery')),
    },
    '/resource/video': {
      component: dynamicWrapper(app, ['resource'], () => import('../routes/Resource/video')),
    },
    '/terminal/campus': {
      component: dynamicWrapper(app, ['campus'], () => import('../routes/Campus')),
    },
    '/terminal/user': {
      component: dynamicWrapper(app, ['terminal'], () => import('../routes/Terminal')),
    },
    '/merchant': {
      component: dynamicWrapper(app, ['merchant/merchant'], () => import('../routes/Merchant')),
    },
    '/merchant/add': {
      component: dynamicWrapper(app, ['merchant/detail'], () => import('../routes/Merchant/detail')),
      name: '添加厂商',
    },
    '/merchant/edit/:id': {
      component: dynamicWrapper(app, ['merchant/detail'], () => import('../routes/Merchant/detail')),
      name: '修改厂商',
    },
    '/tag/tagGroup': {
      component: dynamicWrapper(app, ['group/group', 'merchant/merchant'], () => import('../routes/TagGroup/List')),
    },
    '/tag/tagGroup/add': {
      component: dynamicWrapper(app, ['group/detail', 'merchant/merchant'], () => import('../routes/TagGroup/Edit')),
      name: '添加标签组',
    },
    '/tag/tagGroup/edit/:id': {
      component: dynamicWrapper(app, ['group/detail', 'merchant/merchant'], () => import('../routes/TagGroup/Edit')),
      name: '修改标签组',
    },
    '/tag/tagItem': {
      component: dynamicWrapper(app, ['tag/tag', 'merchant/merchant'], () => import('../routes/Tag/List')),
    },
    '/tag/tagItem/add': {
      component: dynamicWrapper(app, ['tag/detail', 'group/group'], () => import('../routes/Tag/Edit')),
      name: '添加标签',
    },
    '/tag/tagItem/edit/:id': {
      component: dynamicWrapper(app, ['tag/detail', 'group/group'], () => import('../routes/Tag/Edit')),
      name: '修改标签',
    },
    '/product/ware': {
      component: dynamicWrapper(app, ['ware/ware'], () => import('../routes/Ware')),
    },
    '/product/ware/add': {
      component: dynamicWrapper(app, ['ware/detail', 'resource'], () => import('../routes/Ware/detail')),
      name: '添加课件',
    },
    '/product/ware/edit/:id': {
      component: dynamicWrapper(app, ['ware/detail', 'resource'], () => import('../routes/Ware/detail')),
      name: '修改课件',
    },
    '/product/lesson': {
      component: dynamicWrapper(app, ['lesson/lesson'], () => import('../routes/Lesson')),
    },
    '/product/lesson/add': {
      component: dynamicWrapper(app, ['lesson/detail', 'ware/ware'], () => import('../routes/Lesson/detail')),
      name: '添加课',
    },
    '/product/lesson/edit/:id': {
      component: dynamicWrapper(app, ['lesson/detail', 'ware/ware'], () => import('../routes/Lesson/detail')),
      name: '修改课',
    },
    '/product/course': {
      component: dynamicWrapper(app, ['course/course'], () => import('../routes/Course/List')),
    },
    '/product/course/add': {
      component: dynamicWrapper(app, ['course/detail', 'resource', 'lesson/lesson', 'support/support', 'merchant/merchant'], () => import('../routes/Course/Edit')),
      name: '添加课程',
    },
    '/product/course/edit/:id': {
      component: dynamicWrapper(app, ['course/detail', 'resource', 'lesson/lesson', 'support/support', 'merchant/merchant'], () => import('../routes/Course/Edit')),
      name: '修改课程',
    },
    '/product/support': {
      component: dynamicWrapper(app, ['support/support'], () => import('../routes/Support')),
    },
    '/product/support/add': {
      component: dynamicWrapper(app, ['support/detail', 'resource', 'support/support', 'merchant/merchant'], () => import('../routes/Support/detail')),
      name: '添加配套',
    },
    '/product/support/edit/:id': {
      component: dynamicWrapper(app, ['support/detail', 'resource', 'support/support', 'merchant/merchant'], () => import('../routes/Support/detail')),
      name: '修改配套',
    },
    '/product/package': {
      component: dynamicWrapper(app, ['combo/combo'], () => import('../routes/Combo')),
    },
    '/goods': {
      component: dynamicWrapper(app, ['goods/goods', 'merchant/merchant'], () => import('../routes/Goods/List')),
    },
    '/goods/add': {
      component: dynamicWrapper(app, ['course/course', 'support/support', 'combo/combo', 'merchant/merchant', 'goods/detail'], () => import('../routes/Goods/Add')),
      name: '创建商品',
    },
    '/goods/edit': {
      component: dynamicWrapper(app, ['goods/detail'], () => import('../routes/Goods/Edit')),
      name: '修改商品',
    },
    // '/goods/add': {
    //   component: dynamicWrapper(app, [], () => import('../routes/Goods/GoodsProfile')),
    //   name: '新建商品'
    // },
    // '/product/package/add': {
    //   component: dynamicWrapper(app, ['combo/detail', 'support/support'], () => import('../routes/Combo/detail')),
    //   name: '添加课程包',
    // },
    // '/product/package/edit/:id': {
    //   component: dynamicWrapper(app, ['combo/detail', 'support/support'], () => import('../routes/Combo/detail')),
    //   name: '修改课程包',
    // },
    '/order': {
      component: dynamicWrapper(app, ['order/order'], () => import('../routes/Order')),
    },
    // '/order/add': {
    //   component: dynamicWrapper(app, ['order/detail'], () => import('../routes/Order/detail')),
    //   name: '新建订单',
    // },
    // '/order/edit/:id': {
    //   component: dynamicWrapper(app, ['order/detail'], () => import('../routes/Order/detail')),
    //   name: '修改订单',
    // },
    '/order/profile/:id': {
      component: dynamicWrapper(app, ['order/detail'], () => import('../routes/Order/detail/orderProfile')),
      name: '订单详情',
    },
    '/user': {
      component: dynamicWrapper(app, [], () => import('../layouts/UserLayout')),
    },
    '/user/login': {
      component: dynamicWrapper(app, ['login'], () => import('../routes/Login')),
    },
    '/cms/user': {
      component: dynamicWrapper(app, ['cmsUser'], () => import('../routes/CmsUser')),
    },
  };
  // Get name from ./menu.js or just set it in the router data.
  const menuData = getFlatMenuData(getMenuData());
  const routerDataWithName = {};
  Object.keys(routerData).forEach((item) => {
    routerDataWithName[item] = {
      ...routerData[item],
      name: routerData[item].name || menuData[item.replace(/^\//, '')],
    };
  });
  return routerDataWithName;
};
