import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { Divider, Popconfirm, message, Button, Card, Table, Input } from 'antd';
import styles from './index.less';

export default class CardValuation extends PureComponent {
  static propTypes = {
    value: PropTypes.array.isRequired,
    cardTitle: PropTypes.string,
  };

  constructor(props) {
    super(props);

    this.state = {
      data: props.value,
    }
  }

  componentWillReceiveProps(nextProps) {
    if ('value' in nextProps) {
      this.setState({
        data: nextProps.value,
      });
    }
  }

  getRowByKey(key) {
    return this.state.data.filter(item => item.key === key)[0];
  }

  index = 0;
  cacheOriginData = {};
  // 切换编辑状态
  toggleEditable(e, key) {
    e.preventDefault();
    const target = getRowByKey(key);
    if (target) {
      // 进入编辑状态时缓存原始数据
      if (!target.editable) {
        this.cacheOriginData[key] = { ...target };
      }
      target.editable = !target.editable;
      this.setState({ data: [...this.state.data] });
    }
  }

  // 删除一行
  remove(key) {
    const newData = this.state.data.filter(item => item.key !== key);
    this.setState({ data: newData });
    this.props.onChange(newData);
  }

  // 表格新建一行
  newMember = () => {
    const newData = [...this.state.data];
    newData.push({
      key: `NEW_TEMP_ID_${this.index}`,
      chargeUnit: '',
      cpPrice: '',
      merchantPrice: '',
      terminalPrice: '',
      editable: true,
      isNew: true,
    });
    this.index += 1;
    this.setState({ data: newData });
  }

  // 编辑状态，回车直接保存
  handleKeyPress(e, key) {
    if (e.key === 'Enter') {
      this.saveRow(e, key);
    }
  }

  // input输入值变化
  handleFieldChange(e, fieldName, key) {
    const newData = [...this.state.data];
    const target = this.getRowByKey(key);
    if (target) {
      target[fieldName] = e.target.value;
      this.setState({ data: newData });
    }
  }

  // 保存
  saveRow(e, key) {
    e.persist();
    // save field when blur input
    setTimeout(() => {
      if (document.activeElement.tagName === 'INPUT' &&
          document.activeElement !== e.target) {
        return;
      }
      if (this.clickedCancel) {
        this.clickedCancel = false;
        return;
      }
      const target = this.getRowByKey(key) || {};
      // if (!target.chargeUnit || !target.terminalPrice || !target.department) {
      //   message.error('请填写完整成员信息。');
      //   e.target.focus();
      //   return;
      // }
      delete target.isNew;
      this.toggleEditable(e, key);
      this.props.onChange(this.state.data);
    }, 10);
  }

  // 取消编辑
  cancel(e, key) {
    this.clickedCancel = true;
    e.preventDefault();
    const target = this.getRowByKey(key);
    if (this.cacheOriginData[key]) {
      Object.assign(target, this.cacheOriginData[key]);
      target.editable = false;
      delete this.cacheOriginData[key];
    }
    this.setState({ data: [...this.state.data] });
  }

  render() {
    const { cardTitle } = this.props;
    const columns = [{
      title: '计价单位',
      dataIndex: 'chargeUnit',
      key: 'chargeUnit',
      render: (text, record) => {
        if (record.editable) {
          return (
            <Input
              value={text}
              autoFocus
              placeholder="输入计价单位,如:`季`/`月/`年`/`件`等"
            />
          );
        }
        return text;
      },
    },{
      title: '供应商价格(¥)',
      dataIndex: 'cpPrice',
      key: 'cpPrice',
      render: (text, record) => {
        if (record.editable) {
          return (
            <Input
              value={text}
              autoFocus
              placeholder="请输入价格"
            />
          );
        }
        return text;
      }
    },{
      title: '渠道方价格(¥)',
      dataIndex: 'merchantPrice',
      key: 'merchantPrice',
      render: (text, record) => {
        if (record.editable) {
          return (
            <Input
              value={text}
              autoFocus
              placeholder="请输入渠道价格"
            />
          );
        }
        return text;
      },
    },{
      title: '终端价格(¥)',
      dataIndex: 'terminalPrice',
      key: 'terminalPrice',
      render: (text, record) => {
        if (record.editable) {
          return (
            <Input
              value={text}
              autoFocus
              placeholder="请输入终端价格"
            />
          );
        }
      }
    },{
      title: '操作',
      key: 'action',
      render: (text, record) => {
        if (record.editable) {
          if (record.isNew) {
            return (
              <span>
                <a>保存</a>
                <Divider type="vertical" />
                <Popconfirm title="是否要删除此行？" onConfirm={() => this.remove(record.key)}>
                  <a>删除</a>
                </Popconfirm>
              </span>
            );
          }
          return (
            <span>
              <a>保存</a>
              <Divider type="vertical" />
              <a onClick={e => this.cancel(e, record.key)}>取消</a>
            </span>
          );
        }
        return (
          <span>
            <a onClick={e => this.toggleEditable(e, record.key)}>编辑</a>
            <Divider type="vertical" />
            <Popconfirm title="是否要删除此行？" onConfirm={() => this.remove(record.key)}>
              <a>删除</a>
            </Popconfirm>
          </span>
        );
      }
    }];
    return (
      <Card title={cardTitle} bordered={false}>
        <Table
          bordered={true}
          columns={columns}
          pagination={false}
          dataSource={[]}
          rowClassName={(record) => {
            return record.editable ? styles.editable : '';
          }}
        />
        <Button
          onClick={this.newMember}
          style={{ width: '100%', marginTop: 16, marginBottom: 8 }}
          type="dashed"
          icon="plus"
        >新增价格类型
        </Button>
      </Card>
    );
  }
}
