import React from 'react';
import PropTypes from 'prop-types';
import { Form, Cascader, Input, Modal, Icon } from 'antd';
import * as city from '../../utils/city';

const FormItem = Form.Item

const formItemLayout = {
  labelCol: {
    span: 7,
  },
  wrapperCol: {
    span: 14,
  },
}

const ModalForm = ({
  item = {},
  onOk,
  form: {
    getFieldDecorator,
    getFieldsValue,
    validateFields,
  },
  ...modalProps,
}) => {
  const handleOk = () => {
    validateFields((errors) => {
      if (errors) {
        return
      }
      const data = {
        ...getFieldsValue(),
      };
      data.provinceCode = city.provNameToCode(data.cascader[0]);
      data.cityName = data.cascader.slice(1, 3).join(' ');
      delete data.cascader;
      item.id ? data.id = item.id : null;
      onOk(data);
    })
  }

  const modalOpts = {
    ...modalProps,
    onOk: handleOk,
  }

  return (
    <Modal {...modalOpts}>
      <Form layout="horizontal">
        <FormItem label="校区编号：" hasFeedback {...formItemLayout}>
          {getFieldDecorator('code', {
            initialValue: item.code,
            rules: [
              {
                required: true,
                message: '校区编号为必填项！',
              },
            ],
          })(<Input disabled={item.code ? true : false}/>)}
        </FormItem>
        <FormItem label="校区地址" hasFeedback {...formItemLayout}>
          {getFieldDecorator('cascader', {
            rules: [
              {
                required: true,
                message: '校区地址为必选项！'
              }
            ],
            initialValue: item.provinceCode && [city.provCodeToName(item.provinceCode), ...(item.cityName || '').split(' ')],
          })(<Cascader
            style={{ width: '100%' }}
            options={city.DICT_FIXED}
            placeholder="请选择地址"
          />)}
        </FormItem>
        <FormItem label="校区名称：" hasFeedback {...formItemLayout}>
          {getFieldDecorator('zoneName', {
            initialValue: item.zoneName,
            rules: [
              {
                required: true,
                message: '校区名称为必填项！',
              },
            ],
          })(<Input placeholder="只填写学校名称即可"/>)}
        </FormItem>
        <FormItem label="联系人：" hasFeedback {...formItemLayout}>
          {getFieldDecorator('contactName', {
            initialValue: item.contactName,
            rules: [
              {
                required: true,
                message: '联系人为必填项！',
              },
            ],
          })(<Input />)}
        </FormItem>
        <FormItem label="联系电话：" hasFeedback {...formItemLayout}>
          {getFieldDecorator('mobile', {
            initialValue: item.mobile,
            rules: [
              {
                required: true,
                message: '联系电话为必填项！',
              },
            ],
          })(<Input />)}
        </FormItem>
        <FormItem label="收货地址" hasFeedback {...formItemLayout}>
          {getFieldDecorator('address', {
            initialValue: item.address,
          })(<Input />)}
        </FormItem>
        <FormItem label="银行账户" hasFeedback {...formItemLayout}>
          {getFieldDecorator('bankAccount', {
            initialValue: item.bankAccount,
          })(<Input />)}
        </FormItem>
        <FormItem label="开户行名称" hasFeedback {...formItemLayout}>
          {getFieldDecorator('depositBank', {
            initialValue: item.depositBank,
          })(<Input />)}
        </FormItem>
      </Form>
    </Modal>
  )
}

ModalForm.propTypes = {
  item: PropTypes.object,
  form: PropTypes.object,
  type: PropTypes.string,
  onOk: PropTypes.func,
}

export default Form.create()(ModalForm);
