import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { Card, Form, Switch, Radio, Button, Input } from 'antd';
import { domains } from '../../../utils/config';

const FormItem = Form.Item;
const RadioGroup = Radio.Group;

@Form.create()
export default class BaseInfoCard extends PureComponent {
  static propTypes = {
    form: PropTypes.object.isRequired,
    item: PropTypes.object.isRequired,
  };

  render() {
    const { form: { getFieldDecorator }, item, onCancel } = this.props;

    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 7 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 12 },
        md: { span: 10 },
      },
    };

    const submitFormLayout = {
      wrapperCol: {
        xs: { span: 24, offset: 0 },
        sm: { span: 10, offset: 7 },
      },
    };


    return (
      <Card title="基础信息">
        <Form layout="horizontal">
          <FormItem label="厂商编号" hasFeedback {...formItemLayout}>
            {getFieldDecorator('code',{
              rules: [{ required: true, type: 'string', message: '编号为必填写!' }],
              initialValue: item.code,
            })(<Input />)}
          </FormItem>
          <FormItem label="厂商名称" hasFeedback {...formItemLayout}>
            {getFieldDecorator('name',{
              rules: [{ required: true, type: 'string', message: '名称为必填项!' }],
              initialValue: item.name,
            })(<Input />)}
          </FormItem>
          <FormItem label="厂商类型" {...formItemLayout}>
            {getFieldDecorator('domain',{
              initialValue: item.domain || 2010,
            })(<RadioGroup>{Object.keys(domains).map(key => <Radio value={Number(key)} key={`domain-${key}`}>{domains[key]}</Radio>)}</RadioGroup>)}
          </FormItem>
          <FormItem label="开户银行" hasFeedback {...formItemLayout}>
            {getFieldDecorator('depositBank',{
              initialValue: item.depositBank,
            })(<Input />)}
          </FormItem>
          <FormItem label="银行账户" hasFeedback {...formItemLayout}>
            {getFieldDecorator('bankAccount',{
              initialValue: item.bankAccount,
            })(<Input />)}
          </FormItem>
          <FormItem label="营业执照编号" hasFeedback {...formItemLayout}>
            {getFieldDecorator('licenseId',{
              initialValue: item.licenseId,
            })(<Input />)}
          </FormItem>
          <FormItem label="纳税人识别号" hasFeedback {...formItemLayout}>
            {getFieldDecorator('taxNumber',{
              initialValue: item.taxNumber,
            })(<Input />)}
          </FormItem>
          <FormItem label="发票类型" {...formItemLayout}>
            {getFieldDecorator('receiptType', {
              initialValue: item.receiptType || 'SPECIAL',
            })(
              <RadioGroup>
                <Radio value="COMMON" key="receipt-com">普通发票</Radio>
                <Radio value="SPECIAL" key="receipt-spl">增值税发票</Radio>
              </RadioGroup>
            )}
          </FormItem>
          <FormItem {...submitFormLayout} style={{ marginTop: 32 }}>
            <Button onClick={onCancel}>取消</Button>
            <Button type="primary" style={{ marginLeft: 35 }} htmlType="submit">提交</Button>
          </FormItem>
        </Form>
      </Card>
    );
  }
}
