import { stringify } from 'qs';
import request from '../utils/request';
import { product } from '../utils/api';

/**
 * @desc 获取全部产品 /product
 */
export async function query(params) {
  return request(`${product}?${stringify(params)}`);
}

/**
 * @desc 获取一个产品 /product/<productId>
 */
export async function queryOne({ id }) {
  return request(`${product}/${id}`);
}

/**
 * @desc 创建一个产品
 */
export async function create(params) {
  const { type, ...rest } = params;
  const options = {
    method: 'POST',
    body: JSON.stringify(rest),
  };
  return request(`${product}?type=${type}`, options);
}

/**
 * @desc 修改一个产品 put /product/<productId>
 */
export async function update(params) {
  const { id, ...rest } = params;
  const options = {
    method: 'PUT',
    body: JSON.stringify(rest),
  };
  return request(`${product}/${id}`, options);
}

/**
 * @desc 下架一个产品 delete /product/<productId>
 */
export async function remove({ id }) {
  const options = { method: 'DELETE' }
  return request(`${product}/${id}`, options);
}
